==> bootstrap-2.7.1.tgz: package/Basket/Basket.esm.js <==
import _extends from "@babel/runtime/helpers/extends";
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export var Basket = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, _extends({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 16 16"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    fillRule: "evenodd",
    d: "M10.243 1.071a.5.5 0 01.686.172l3 5a.5.5 0 11-.858.514l-3-5a.5.5 0 01.172-.686zm-4.486 0a.5.5 0 00-.686.172l-3 5a.5.5 0 10.858.514l3-5a.5.5 0 00-.172-.686z"
  }), /*#__PURE__*/React.createElement("path", {
    fillRule: "evenodd",
    d: "M1 7v1h14V7H1zM.5 6a.5.5 0 00-.5.5v2a.5.5 0 00.5.5h15a.5.5 0 00.5-.5v-2a.5.5 0 00-.5-.5H.5z"
  }), /*#__PURE__*/React.createElement("path", {
    fillRule: "evenodd",
    d: "M14 9H2v5a1 1 0 001 1h10a1 1 0 001-1V9zM2 8a1 1 0 00-1 1v5a2 2 0 002 2h10a2 2 0 002-2V9a1 1 0 00-1-1H2z"
  }), /*#__PURE__*/React.createElement("path", {
    fillRule: "evenodd",
    d: "M4 10a.5.5 0 01.5.5v3a.5.5 0 11-1 0v-3A.5.5 0 014 10zm2 0a.5.5 0 01.5.5v3a.5.5 0 11-1 0v-3A.5.5 0 016 10zm2 0a.5.5 0 01.5.5v3a.5.5 0 11-1 0v-3A.5.5 0 018 10zm2 0a.5.5 0 01.5.5v3a.5.5 0 11-1 0v-3a.5.5 0 01.5-.5zm2 0a.5.5 0 01.5.5v3a.5.5 0 11-1 0v-3a.5.5 0 01.5-.5z"
  }));
});
Basket.displayName = 'Basket';
export var BasketDimensions = {
  height: 16,
  width: 16
};

==> bootstrap-10.15.1.tgz: package/Basket/Basket.esm.js <==
import _extends from "@babel/runtime/helpers/extends";
import * as React from 'react';
import { StyledIconBase } from '@styled-icons/styled-icon';
export var Basket = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(StyledIconBase, _extends({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 16 16"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    fillRule: "evenodd",
    d: "M10.243 1.071a.5.5 0 01.686.172l3 5a.5.5 0 11-.858.514l-3-5a.5.5 0 01.172-.686zm-4.486 0a.5.5 0 00-.686.172l-3 5a.5.5 0 10.858.514l3-5a.5.5 0 00-.172-.686z"
  }), /*#__PURE__*/React.createElement("path", {
    fillRule: "evenodd",
    d: "M1 7v1h14V7H1zM.5 6a.5.5 0 00-.5.5v2a.5.5 0 00.5.5h15a.5.5 0 00.5-.5v-2a.5.5 0 00-.5-.5H.5z"
  }), /*#__PURE__*/React.createElement("path", {
    fillRule: "evenodd",
    d: "M14 9H2v5a1 1 0 001 1h10a1 1 0 001-1V9zM2 8a1 1 0 00-1 1v5a2 2 0 002 2h10a2 2 0 002-2V9a1 1 0 00-1-1H2z"
  }), /*#__PURE__*/React.createElement("path", {
    fillRule: "evenodd",
    d: "M4 10a.5.5 0 01.5.5v3a.5.5 0 11-1 0v-3A.5.5 0 014 10zm2 0a.5.5 0 01.5.5v3a.5.5 0 11-1 0v-3A.5.5 0 016 10zm2 0a.5.5 0 01.5.5v3a.5.5 0 11-1 0v-3A.5.5 0 018 10zm2 0a.5.5 0 01.5.5v3a.5.5 0 11-1 0v-3a.5.5 0 01.5-.5zm2 0a.5.5 0 01.5.5v3a.5.5 0 11-1 0v-3a.5.5 0 01.5-.5z"
  }));
});
Basket.displayName = 'Basket';
export var BasketDimensions = {
  height: 16,
  width: 16
};
